@@ -33,8 +33,8 @@
 #include <qcombobox.h>
 #include <QPixmap>
 
-#include <klocale.h>
-#include <kdebug.h>
+#include <KLocalizedString>
+#include "ksirk_debug.h"
 
 #define _XOPEN_SOURCE_
 #include <unistd.h>
@@ -53,7 +53,7 @@ KWaitedPlayerSetupDialog::KWaitedPlayerSetupDialog(
   m_password(password), m_result(result)
 {
   setupUi(this);
-  kDebug() << "KWaitedPlayerSetupDialog constructor" << endl;
+  qCDebug(KSIRK_LOG) << "KWaitedPlayerSetupDialog constructor" << endl;
   fillWaitedPlayersCombo();
   
   QObject::connect((const QObject *)PushButton1, SIGNAL(clicked()), this, SLOT(slotOK()) );
@@ -65,7 +65,7 @@ KWaitedPlayerSetupDialog::~KWaitedPlayerSetupDialog(){
 
 void KWaitedPlayerSetupDialog::slotOK()
 {
-  kDebug() << "slotOk" << endl;
+  qCDebug(KSIRK_LOG) << "slotOk" << endl;
   // toport
 //   m_password = QString(crypt(passwordEdit->password(),"T6"));
   m_result = waitedPlayersCombo->currentIndex();
@@ -74,14 +74,14 @@ void KWaitedPlayerSetupDialog::slotOK()
 
 void KWaitedPlayerSetupDialog::fillWaitedPlayersCombo()
 {
-  kDebug() << "Filling nations combo" << endl;
+  qCDebug(KSIRK_LOG) << "Filling nations combo" << endl;
 
   QList<PlayerMatrix>::iterator it, it_end;
   it = m_automaton->game()->waitedPlayers().begin();
   it_end = m_automaton->game()->waitedPlayers().end();
   for (; it != it_end; it++)
   {
-    kDebug() << "Adding waited player " << (*it).name << endl;
+    qCDebug(KSIRK_LOG) << "Adding waited player " << (*it).name << endl;
     QString imgName = m_automaton->game()->theWorld()->nationNamed((*it).nation)->flagFileName();
 //     load image
     QPixmap flag;
@@ -108,4 +108,4 @@ void KWaitedPlayerSetupDialog::fillWaitedPlayersCombo()
 
 }
 
-#include "kwaitedplayersetupdialog.moc"
+
